/*
 * JEdit.java	A simple text editor.
 */
import java.io.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

public class JEdit extends JFrame {

	JTextArea	ta;
	String		clipText;

  public JEdit()
  {
    super( "A Simple Text Editor" );

    clipText = null;

    initMenus();
    initToolBar();
    initTextArea();

    setSize( 900, 700 );
    setLocationRelativeTo( null );
    setDefaultCloseOperation( EXIT_ON_CLOSE );
  }

  public void initMenus()
  {
    // add a menu bar
    JMenuBar mb = new JMenuBar();
    setJMenuBar( mb );

    // add the menus
    JMenu fileMenu, editMenu, helpMenu;
    mb.add( (fileMenu = new JMenu("File")) );
    fileMenu.setMnemonic( KeyEvent.VK_F );
    mb.add( (editMenu = new JMenu("Edit")) );
    mb.add( (helpMenu = new JMenu("Help")) );

    // add menu items
    JMenuItem miOpen, miSave, miExit;
    JMenuItem miCopy, miPaste, miAbout;
    fileMenu.add( (miOpen = new JMenuItem("Open File...")) );
    fileMenu.add( (miSave = new JMenuItem("Save File...")) );
    fileMenu.addSeparator();
    fileMenu.add( (miExit = new JMenuItem("Exit", KeyEvent.VK_X)) );
    editMenu.add( (miCopy = new JMenuItem("Copy")) );
    editMenu.add( (miPaste = new JMenuItem("Paste")) );
    helpMenu.add( (miAbout = new JMenuItem("About")) );
    
    ActionEventHandler ah = new ActionEventHandler();
    miOpen.addActionListener( ah );
    miSave.addActionListener( ah );
    miExit.addActionListener( ah );
    miCopy.addActionListener( ah );
    miPaste.addActionListener( ah );
    miAbout.addActionListener( ah );
  }

  public void initToolBar()
  {
    JToolBar tb = new JToolBar( "Standard" );
    Container cp = getContentPane();
    cp.add( tb, BorderLayout.NORTH );

    JButton ob = new JButton("o");
    ob.setToolTipText( "Open File..." );
    JButton sb = new JButton("s");
    sb.setToolTipText( "Save File..." );
    JButton cb = new JButton("c");
    cb.setToolTipText( "Copy" );
    JButton pb = new JButton("p");
    pb.setToolTipText( "Paste" );

    ActionEventHandler ah = new ActionEventHandler();
    ob.addActionListener( ah );
    sb.addActionListener( ah );
    cb.addActionListener( ah );
    pb.addActionListener( ah );
    tb.add( ob );
    tb.add( sb );
    tb.add( cb );
    tb.add( pb );
  }

  public void initTextArea()
  {
    ta = new JTextArea();
    Container cp = getContentPane();
    cp.add( new JScrollPane(ta), BorderLayout.CENTER );
  }

  public void fopen()
  {
    JFileChooser fc = new JFileChooser();

    int status = fc.showOpenDialog( this );
    if( status == JFileChooser.APPROVE_OPTION )
    {
      ta.setText("");
      File f = fc.getSelectedFile();
      try
      {
        BufferedReader br = new BufferedReader( new FileReader(f) );
        String line;
        while( (line = br.readLine()) != null )
          ta.append( line + "\n" );
        br.close();
      }
      catch( Exception e )
      {
        System.err.println( "failed to read from " + f );
      }
    }
  }

  public void fsave()
  {
    JFileChooser fc = new JFileChooser();

    int status = fc.showSaveDialog( this );
    if( status == JFileChooser.APPROVE_OPTION )
    {
      File f = fc.getSelectedFile();
      try
      {
        BufferedWriter bw = new BufferedWriter( new FileWriter(f) );
        bw.write( ta.getText() );
        bw.close();
      }
      catch( Exception e )
      {
        System.err.println( "failed to save to " + f );
      }
    }
  }

  class ActionEventHandler implements ActionListener {

    public ActionEventHandler() {}

    public void actionPerformed( ActionEvent e )
    {
      String cmd = e.getActionCommand();

      if( cmd.equals("Open File...") || cmd.equals("o") )
        fopen();

      else if( cmd.equals("Save File...") || cmd.equals("s") )
        fsave();

      else if( cmd.equals("Copy") || cmd.equals("c") )
        clipText = ta.getSelectedText();

      else if( cmd.equals("Paste") || cmd.equals("p") )
      {
        if( clipText != null ) ta.append( clipText );
      }

      else if( cmd.equals("About") )
        JOptionPane.showMessageDialog( null, "JEdit - A Simple " +
          "Text Editor by csun@calstatela.edu" );

      else if( cmd.equals("Exit") )
      {
        System.out.println( "Bye bye." );
        System.exit(0);
      }

      else
        System.out.println( cmd + " is not implemented yet." );
    }

  } // end of class ActionEventHandler


  public static void main( String args[] )
  {
    JEdit f = new JEdit();
    // f.setVisible( true );
    f.show();
  }

} // end of class JEdit

